@@ -106,11 +106,11 @@ class SimsContext(SuperContext):
     want_slot_data = True
     tags = {"AP"}
 
-    def __init__(self, server_address, slot_name, password, ready_callback=None, error_callback=None):
+    def __init__(self, server_address, password, ready_callback=None, error_callback=None):
         super().__init__(server_address, password)
         self.ready_callback = ready_callback
         self.error_callback = error_callback
-        self.username = slot_name
+        self.username = urllib.parse.urlparse(server_address).username
         self.syncing = False
         self.goal = None
         self.career = None
@@ -220,7 +220,7 @@ async def game_watcher(ctx: SimsContext):
             sync_msg = [{'cmd': 'Sync'}]
             await ctx.send_msgs(sync_msg)
             ctx.syncing = False
-        if (ctx.server and ctx.slot) is not None:
+        if ctx.server is not None and ctx.slot is not None:
             json_data = load_json('locations_cached.json')
             if json_data is not None:
                 if "Locations" in json_data and json_data["Locations"] is not None and json_data["Seed"] == ctx.seed_name:
@@ -248,7 +248,7 @@ async def game_watcher(ctx: SimsContext):
         await asyncio.sleep(0.5)
 
 
-def launch(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def launch(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """
     Launch the client
     """
@@ -256,7 +256,7 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
     logging.getLogger("Sims4Client")
 
     async def main():
-        ctx = SimsContext(server_address, slot_name, password, ready_callback, error_callback)
+        ctx = SimsContext(server_address, password, ready_callback, error_callback)
         if ctx._can_takeover_existing_gui():
             await ctx._takeover_existing_gui() 
         else:
@@ -294,9 +294,9 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
             error_callback()
 
 
-def main(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def main(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """Main entry point for integration with MultiWorld system"""
-    launch(server_address, slot_name, password, ready_callback, error_callback)
+    launch(server_address, password, ready_callback, error_callback)
 
 
 if __name__ == "__main__":
