@@ -1,8 +1,7 @@
 from . import Sims4World, Sims4Web
-from .Client import launch
 
 """
-The Sims 4 World Registration
+Sims 4 World Registration
 
 This file contains the metadata and class references for the sims4 world.
 """
@@ -20,4 +19,4 @@ VERSION = version
 # Plugin entry points
 WORLD_CLASS = Sims4World
 WEB_WORLD_CLASS = Sims4Web
-CLIENT_FUNCTION = launch
+CLIENT_FUNCTION = None
